@@ -7,7 +7,7 @@ class PackPOOII():
     def __init__(self):
         pass
 
-    def subString(self, palavra):
+    def subString(self, string, palavra):
         """ Procura uma sub-string dentro de uma determinada string
 
         Parametros
@@ -17,11 +17,23 @@ class PackPOOII():
     
         """
         total = 0
-        for letras in range(len(palavra)):
-            if(palavra[letras: letras+6] == "banana"):
+        for letras in range(len(string)):
+            if(string[letras: letras+6] == palavra):
                 total += 1
-        return total
+        return [palavra, total]
     
+    def inverte(self, palavra): 
+        """ Inverte uma string
+
+        Parametros
+        ----------
+        palavra : str
+        Endereço da string 
+    
+        """
+        palavra = palavra[::-1] 
+        return palavra
+
 
     def deleteLine(self, arq_text, linha):
         """ Deleta uma linha de um arquivo de texto
